@@ -67,7 +67,7 @@ if (file_exists($MODULE.'/pre_init.php')) {
 
 require 'SPAF2/Application.php';
 
-if ((! isset($SP_CONFIG)) && (! isset($configfile))) {
+if (! isset($configfile)) {
     echo "Main configfile not set!";
     exit();
 }
@@ -196,7 +196,7 @@ if (file_exists($MODULE.'/post_ctrl.php')) {
  * controller will not checked for authorization.
  *
  */
-$App->log("VIEW[$ACCESS_LEVEL]) ".$App->view,2,'SPAF2');
+$App->log("VIEW[$ACCESS_LEVEL] ".$App->view,2,'SPAF2');
 // check if file exists or call default view file. The default view
 // will not checked for authorization.
 $SP_FILE = $MODULE.'/view/' . $App->view . '.php';
