@@ -290,7 +290,7 @@ class Application extends ApplicationConfig
 
         $AppConfig = new ApplicationConfig($this->configdir);
         $this->config = $AppConfig->load(basename($configfile));
-        $this->authz = $AppConfig->load($this->getConfig('AUTHORIZATION','benno-authz.conf'));
+        $this->authz = $AppConfig->load($this->getConfig('AUTHORIZATION','/usr/share/benno-web/benno-authz.conf'));
 
         $this->module   = $MODULE;
         $this->_request = & $_REQUEST;
