@@ -87,6 +87,19 @@ catch (Exception $e) {
 }
 try {
     $body_content = $EMail->getBody($body_type);
+
+    if ((!$showImgs) && ($body_type == 'text/html'))  {    // remove images
+        $body_content = preg_replace('/url\(.+?\)/','url(/* removed */)',$body_content);
+        $dom = new DOMDocument();
+        @$dom->loadHTML($body_content);
+        $tags = @$dom->getElementsByTagName('img');
+        foreach ($tags as $tag) {
+            @$tag->getAttributeNode('src')->value = '';
+        }
+        $body_content = $dom->saveHTML();
+        // remove url in css
+    }
+
 }
 catch (Exception $e) {
     $App->log('Cannot fetch email body: '.$e->getMessage(),1,'a_showEmail');
