@@ -32,7 +32,7 @@
  */
 
 $RESTconf = new ApplicationConfig($App->configdir);
-$RESTconf->load($App->getConfig('REST_CONFIG','rest.conf'));
+$RESTconf->load($App->getConfig('REST_CONFIG','/etc/benno-web/rest.conf'));
 
 // defaults: compatibility to deprecated configuration
 $base_url  = $RESTconf->getConfig('BASE_URL','http://localhost:21080');
@@ -69,7 +69,7 @@ $filterQuery   = 'filterQuery='.$filterString;
 $query_request = $filterQuery.'&'.$archive.'&'.$query_request;
 
 // remove possible filter entries from query
-$url = $base_url.'/'.$rest_path.'/?'.$query_request;
+$url = $base_url.'/'.$rest_path.'/';
 
 // Open the cURL session
 $curl = curl_init();
@@ -77,6 +77,8 @@ $curl = curl_init();
 curl_setopt($curl, CURLOPT_URL, $url);
 curl_setopt($curl, CURLOPT_HEADER, 1);
 curl_setopt($curl, CURLOPT_USERPWD, $rest_user.':'.$rest_pass);
+curl_setopt($curl, CURLOPT_POST, 1);
+curl_setopt($curl, CURLOPT_POSTFIELDS, $query_request);
 
 curl_setopt($curl, CURLOPT_RETURNTRANSFER,1);
 curl_setopt($curl, CURLOPT_TIMEOUT,30);
